about summary refs log tree commit diff
path: root/compiler/rustc_middle/src/query
diff options
context:
space:
mode:
authorMatthew Jasper <mjjasper1@gmail.com>2020-06-23 17:57:24 +0100
committerMatthew Jasper <mjjasper1@gmail.com>2020-10-06 11:18:45 +0100
commit0eb87ed55fa76e11777254c77ff7f11c74aa2bfa (patch)
tree46ee3d77fd33282b8891bd6329157551b8b7ef69 /compiler/rustc_middle/src/query
parent5ded394553296d56bb66e925d7001ab3271979ce (diff)
downloadrust-0eb87ed55fa76e11777254c77ff7f11c74aa2bfa.tar.gz
rust-0eb87ed55fa76e11777254c77ff7f11c74aa2bfa.zip
Rename projection_predicates to item_bounds
Diffstat (limited to 'compiler/rustc_middle/src/query')
-rw-r--r--compiler/rustc_middle/src/query/mod.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/compiler/rustc_middle/src/query/mod.rs b/compiler/rustc_middle/src/query/mod.rs
index fe115bbb9c3..fadc7621785 100644
--- a/compiler/rustc_middle/src/query/mod.rs
+++ b/compiler/rustc_middle/src/query/mod.rs
@@ -156,7 +156,7 @@ rustc_queries! {
             cache_on_disk_if { key.is_local() }
         }
 
         /// Returns the list of predicates that can be used for
         /// `SelectionCandidate::ProjectionCandidate` and
         /// `ProjectionTyCandidate::TraitDef`.
         /// Specifically this is the bounds (equivalent to) those
@@ -169,7 +169,7 @@ rustc_queries! {
         ///      ^^^^^^^^^^^^^^^
         ///
         /// `key` is the `DefId` of the associated type or opaque type.
-        query projection_predicates(key: DefId) -> &'tcx ty::List<ty::Predicate<'tcx>> {
+        query item_bounds(key: DefId) -> &'tcx ty::List<ty::Predicate<'tcx>> {
             desc { |tcx| "finding projection predicates for `{}`", tcx.def_path_str(key) }
         }
@@ -156,7 +156,7 @@ rustc_queries! {
         }
 
-        /// Returns the list of predicates that can be used for
+        /// Returns the list of bounds that can be used for
         /// `SelectionCandidate::ProjectionCandidate` and
         /// `ProjectionTyCandidate::TraitDef`.